@@ -2,10 +2,7 @@ from base64 import b64decode, b64encode
 from hmac import new as hmac
 import json
 import hashlib
-try:
-	import ujson as json
-except ImportError:
-	import json
+import json
 
 def add_padding (s):
 	paddings = 4 - (len (s) % 4)
